[llvm-commits] CVS: llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp

Evan Cheng evan.cheng at apple.com
Mon Mar 12 16:37:28 PDT 2007



Changes in directory llvm/lib/CodeGen/SelectionDAG:

TargetLowering.cpp updated: 1.95 -> 1.96
---
Log message:

More flexible TargetLowering LSR hooks for testing whether an immediate is a legal target address immediate or scale.

---
Diffs of the changes:  (+13 -3)

 TargetLowering.cpp |   16 +++++++++++++---
 1 files changed, 13 insertions(+), 3 deletions(-)


Index: llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp
diff -u llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp:1.95 llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp:1.96
--- llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp:1.95	Sat Feb 24 19:28:05 2007
+++ llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp	Mon Mar 12 18:37:10 2007
@@ -1931,15 +1931,25 @@
 //  Loop Strength Reduction hooks
 //===----------------------------------------------------------------------===//
 
-/// isLegalAddressImmediate - Return true if the integer value or
-/// GlobalValue can be used as the offset of the target addressing mode.
-bool TargetLowering::isLegalAddressImmediate(int64_t V) const {
+/// isLegalAddressImmediate - Return true if the integer value can be used as
+/// the offset of the target addressing mode for load / store of the given
+/// type.
+bool TargetLowering::isLegalAddressImmediate(int64_t V, const Type *Ty) const {
   return false;
 }
+
+/// isLegalAddressImmediate - Return true if the GlobalValue can be used as
+/// the offset of the target addressing mode.
 bool TargetLowering::isLegalAddressImmediate(GlobalValue *GV) const {
   return false;
 }
 
+/// isLegalAddressScale - Return true if the integer value can be used as the
+/// scale of the target addressing mode for load / store of the given type.
+bool TargetLowering::isLegalAddressScale(int64_t S, const Type *Ty) const {
+  return false;
+}
+
 
 // Magic for divide replacement
 






More information about the llvm-commits mailing list